
import xhr from 'src/utils/xhr/microXhr';

export default class courseMicroSrv{
  
  
   /**
   * 获取课程课时列表
   * @param { number } id - 课程编号
   * @return {Promise<any>}
   */  
  static getCourseLessonList({ id }) {
    return xhr({
      url: `/edu/course/${id}/lessonList`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课程关联的商品
   * @param { number } id - 课程编号
   * @return {Promise<any>}
   */  
  static getCourseGoods({ id }) {
    return xhr({
      url: `/edu/course/${id}/goods`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课程课件列表
   * @param { int } id - 课程ID
   * @return {Promise<any>}
   */  
  static courseWareList({ id }) {
    return xhr({
      url: `/edu/course/${id}/courseWareList`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 批量下载课件
   * @return {Promise<any>}
   */  
  static batchDownload() {
    return xhr({
      url: `/edu/course/${id}/batchDownload`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课程课件的下载地址url
   * @param { array } idList - id参数列表
   * @return {Promise<any>}
   */
  static wareInfoList({ idList }) {
    return xhr({
      method: 'post',
      url: `/edu/course/wareInfoList`,
      data: { idList },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课程信息,APP同步课程信息
   * @param { array } idList - 课程ID列表
   * @return {Promise<any>}
   */
  static info({ idList }) {
    return xhr({
      method: 'post',
      url: `/edu/course/info`,
      data: { idList },
      custom: arguments[1]
    })
  }
  
   /**
   * 通过直播id获取课程详情
   * @param { string } id - 直播
   * @return {Promise<any>}
   */  
  static getCourseInfoByLiveId({ id }) {
    return xhr({
      url: `/edu/appCourse/getCourseInfoByLiveId`,
      params: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课程课时列表
   * @param { int } id - 课程ID
   * @return {Promise<any>}
   */  
  static newLessonList({ id }) {
    return xhr({
      url: `/edu/course/${id}/newLessonList`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取课时课件
   * @param { int } id - 课时ID
   * @return {Promise<any>}
   */  
  static courseWare({ id }) {
    return xhr({
      url: `/edu/course/${id}/courseWare`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 返回需要同步的资源
   * @param { string } token - 秘钥
   * @return {Promise<any>}
   */
  static syncResource({ token }) {
    return xhr({
      method: 'post',
      url: `/edu/external/syncResource`,
      data: { token },
      custom: arguments[1]
    })
  }
  
   /**
   * 接收同步结果
   * @param { string } token - 
   * @param { string } courseId - 
   * @param { string } status - 
   * @return {Promise<any>}
   */
  static syncResourceStatus({ token, courseId, status }) {
    return xhr({
      method: 'post',
      url: `/edu/external/syncResourceStatus`,
      data: { token, courseId, status },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取讲义列表(pc端接口）
   * @param { int } id - 111
   * @return {Promise<any>}
   */  
  static courseNoteList({ id }) {
    return xhr({
      url: `/edu/course/${id}/courseNoteList`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取包含章节信息的讲义列表（移动版使用）
   * @param { number } id - 
   * @return {Promise<any>}
   */  
  static getCourseNoteListWithChapter({ id }) {
    return xhr({
      url: `/edu/course/${id}/courseNoteListWithChapter`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 批量下载讲义或课件
   * @param { string } fileIDs - 用_拼接的fileID
   * @param { string } fileType - ["coursenote","courseware"]
   * @return {Promise<any>}
   */  
  static batchDownloadCourseAccessory({ fileIDs, fileType }) {
    return xhr({
      url: `/edu/course/${id}/batchDownloadCourseAccessory`,
      params: { fileIDs, fileType },
      custom: arguments[1]
    })
  }
}