
import xhr from 'src/utils/xhr/microXhr';

export default class liveSrv{
  
  
   /**
   * 获取直播信息-getLiveInfo
   * @param { undefined } ID - 
   * @return {Promise<any>}
   */  
  static getLiveInfo({ ID }) {
    return xhr({
      url: `/edu/live/getLiveInfo`,
      params: { ID },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取直播预告(用户个人的)-getPrevueLive
   * @param { number } isAllLive - 1所有0欢拓
   * @return {Promise<any>}
   */  
  static preLive({ isAllLive }) {
    return xhr({
      url: `/users/preLive`,
      params: { isAllLive },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取机构信息-getTranInfo
   * @return {Promise<any>}
   */  
  static getTranInfo() {
    return xhr({
      url: `/edu/live/getTranInfo`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取我的回放直播列表-getPlaybackLive
   * @param { int } page - 分页的 index
   * @param { int } pageSize - 分页的 pageSize
   * @param { int } sortCourse - 筛选的 course id  默认 0  则是查所有的 默认 0
   * @param { int } sortClassroom - 筛选的 classroom id    则是查所有的 默认 0
   * @param { int } isAllLive - 1所有0欢拓
   * @return {Promise<any>}
   */
  static replayLive({ page, pageSize, sortCourse, sortClassroom, isAllLive }) {
    return xhr({
      method: 'post',
      url: `/users/replayLive`,
      data: { page, pageSize, sortCourse, sortClassroom, isAllLive },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取我的直播回放的班级id和课程id-getLiveIdAndClassIdByReplayLive
   * @return {Promise<any>}
   */  
  static getLiveIdAndClassIdByReplayLive() {
    return xhr({
      url: `/users/getLiveIdAndClassIdByReplayLive`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取全网7天内前4个直播预告-homeLivePrevue
   * @param { int } isAll - 是否获取所有直播
   * @return {Promise<any>}
   */  
  static newHotPreLive({ isAll }) {
    return xhr({
      url: `/live/newHotPreLive`,
      params: { isAll },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取我的回放直播列表(带count返回字段的) -replayLiveWithCount
   * @param { int } page - 分页的 index
   * @param { int } pageSize - 分页的 pageSize
   * @param { int } sortCourse - 筛选的 course id  默认 0  则是查所有的 默认 0
   * @param { int } sortClassroom - 筛选的 classroom id    则是查所有的 默认 0
   * @param { int } isAllLive - 1所有0欢拓
   * @return {Promise<any>}
   */
  static replayLiveWithCount({ page, pageSize, sortCourse, sortClassroom, isAllLive }) {
    return xhr({
      method: 'post',
      url: `/users/replayLiveWithCount`,
      data: { page, pageSize, sortCourse, sortClassroom, isAllLive },
      custom: arguments[1]
    })
  }
  
   /**
   * 预约直播 -liveSubscribe
   * @param { int } id - 直播ID
   * @return {Promise<any>}
   */
  static liveSubscribe({ id }) {
    return xhr({
      method: 'post',
      url: `/live/liveSubscribe`,
      data: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * 进去CC直播间 -enterLiveRoom
   * @param { number } id - 直播id
   * @return {Promise<any>}
   */  
  static enterLiveRoom({ id }) {
    return xhr({
      url: `/live/enterLiveRoom`,
      params: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * App进去CC直播间 -appEnterLiveRoom
   * @param { number } id - 直播id
   * @return {Promise<any>}
   */  
  static appEnterLiveRoom({ id }) {
    return xhr({
      url: `/live/appEnterLiveRoom`,
      params: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * 直播过渡页面-liveTransition
   * @param { number } id - 直播id
   * @return {Promise<any>}
   */  
  static liveTransition({ id }) {
    return xhr({
      url: `/live/liveTransition`,
      params: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * 返回直播状态
   * @return {Promise<any>}
   */  
  static returnLiveStatus?id=3267() {
    return xhr({
      url: `/live/returnLiveStatus?id=3267`,
      params: {},
      custom: arguments[1]
    })
  }
  
   /**
   * 获取直播关联讲义 -liveFile
   * @param { number } liveId - 直播ID
   * @return {Promise<any>}
   */  
  static liveFile?liveId=123({ liveId }) {
    return xhr({
      url: `/live/liveFile?liveId=123`,
      params: { liveId },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取直播课下的讲义列表
   * @param { number } courseId - 课程ID
   * @return {Promise<any>}
   */  
  static liveFileList?courseId=2059({ courseId }) {
    return xhr({
      url: `/live/liveFileList?courseId=2059`,
      params: { courseId },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取直播评分信息-getLiveRating
   * @param { int } webcastID - 直播id
   * @return {Promise<any>}
   */  
  static getLiveRating?webcastID=3614({ webcastID }) {
    return xhr({
      url: `/live/rating/getLiveRating?webcastID=3614`,
      params: { webcastID },
      custom: arguments[1]
    })
  }
  
   /**
   * 提交直播评分-submitLiveRating
   * @param { number } rating - 5
   * @param { number } id - /live/rating/getLiveRating 返回的id
   * @param { string } content - 评价内容
   * @return {Promise<any>}
   */
  static submitLiveRating({ rating, id, content }) {
    return xhr({
      method: 'post',
      url: `/live/rating/submitLiveRating`,
      data: { rating, id, content },
      custom: arguments[1]
    })
  }
  
   /**
   * 无鉴权获取直播课下的讲义列表
   * @param { number } courseId - 课程ID
   * @return {Promise<any>}
   */  
  static liveFileListNotAccess({ courseId }) {
    return xhr({
      url: `/live/liveFileListNotAccess`,
      params: { courseId },
      custom: arguments[1]
    })
  }
  
   /**
   * 批量下载直播讲义-batchDownloadLiveFiles
   * @param { string } liveIDs - 直播ID字符串  '_'号 为分割符
   * @return {Promise<any>}
   */  
  static batchDownloadLiveFiles({ liveIDs }) {
    return xhr({
      url: `/live/batchDownloadLiveFiles`,
      params: { liveIDs },
      custom: arguments[1]
    })
  }
  
   /**
   * 下载直播讲义
   * @param { number } liveID - 直播ID
   * @return {Promise<any>}
   */  
  static downloadLiveFile({ liveID }) {
    return xhr({
      url: `/live/downloadLiveFile`,
      params: { liveID },
      custom: arguments[1]
    })
  }
}