
import xhr from 'src/utils/xhr/microXhr';

export default class newCommentsCommentSrv{
  
  
   /**
   * 获取评论-getCommentList
   * @param { int } commentType - 评论类型(2 课时视频评论|3 题目评论| 4 题目解析视频评论)
   * @param { int } fk - 课时评论，题目解析视频评论:视频ID  |  题目评论:题目ID
   * @param { int } fkSub - 课时评论:课时ID  |  题目解析视频评论:题目ID  |  题目评论:科目ID
   * @param { int } page - 
   * @param { int } pageSize - 
   * @return {Promise<any>}
   */
  static list({ commentType, fk, fkSub, page, pageSize }) {
    return xhr({
      method: 'post',
      url: `/comment/list`,
      data: { commentType, fk, fkSub, page, pageSize },
      custom: arguments[1]
    })
  }
  
   /**
   * 点赞评论-likeComment
   * @param { int } id - 评论ID
   * @return {Promise<any>}
   */
  static likeComment({ id }) {
    return xhr({
      method: 'post',
      url: `/comment/likeComment`,
      data: { id },
      custom: arguments[1]
    })
  }
  
   /**
   * 发表评论-create
   * @param { int } fk - 课时评论，题目解析视频评论:视频ID  |  题目评论:题目ID
   * @param { int } fkSub - 课时评论:课时ID  |  题目解析视频评论:题目ID  |  题目评论:科目ID
   * @param { string } content - 评论内容
   * @param { int } device - 设备类型(1 电脑 2 手机 3 分录小程序 4 初级小程序)
   * @param { int } type - 评论类型(2 课时视频评论|3 题目评论| 4 题目解析视频评论)
   * @return {Promise<any>}
   */
  static create({ fk, fkSub, content, device, type }) {
    return xhr({
      method: 'post',
      url: `/comment/create`,
      data: { fk, fkSub, content, device, type },
      custom: arguments[1]
    })
  }
  
   /**
   * 回复评论-reply
   * @param { string } content - 回复内容
   * @param { int } targetUserID - 目标用户ID
   * @param { int } commentID - 评论ID
   * @param { int } device - 设备类型(1 电脑 2 手机 3 分录小程序 4 初级小程序)
   * @param { string } commentContent - 目标对象的评论内容
   * @return {Promise<any>}
   */
  static reply({ content, targetUserID, commentID, device, commentContent }) {
    return xhr({
      method: 'post',
      url: `/comment/reply`,
      data: { content, targetUserID, commentID, device, commentContent },
      custom: arguments[1]
    })
  }
  
   /**
   * 获取置顶评论-topComment
   * @param { int } commentType - 评论类型(2 课时视频评论|3 题目评论| 4 题目解析视频评论)
   * @param { int } fk - 课时评论，题目解析视频评论:视频ID  |  题目评论:题目ID
   * @param { int } fkSub - 课时评论:课时ID  |  题目解析视频评论:题目ID  |  题目评论:科目ID
   * @return {Promise<any>}
   */
  static top({ commentType, fk, fkSub }) {
    return xhr({
      method: 'post',
      url: `/comment/top`,
      data: { commentType, fk, fkSub },
      custom: arguments[1]
    })
  }
}