import axios from 'axios';
import url from 'url';

axios.defaults.baseURL = ''; // 后端 API 根路径
axios.defaults.withCredentials = true;

import qs from 'qs';
import Cache from './cache';

const xhrCache = new Cache();

axios.defaults.transformRequest = [function (data) {
    if (data && data.noFormData) {
        return JSON.stringify(data)
    } else {
        return qs.stringify(data);
    }
}];

axios.defaults.transformResponse = [function (data) {
    try {
        data = JSON.parse(data, {arrayFormat: 'brackets'});
    } catch (e) {
        data = data;
    }
    return data;
}];

/**
 * @param {{method:string=,url:string,data:object=,cache:bollean=,params:object=}} set
 * @return {*}
 */
const xhr = function (set) {
    const setting = Object.assign({
        method: 'get',
        url: '',
        data: null,
        cache: false,
        params: null,
    }, set);
    let cacheData;
    const cacheKey = url.format({
        pathname: setting.url,
        search: qs.stringify(setting.params),
    });

    if (setting.cache) {
        cacheData = xhrCache.get(cacheKey);
        if (cacheData) {
            return new Promise((resolve) => {
                resolve(cacheData);
            });
        }
    }

    return axios(setting).then((res) => {
        if (setting.cache) {
            // 通过结果判断是否缓存
            if (setting.cache.filter && typeof setting.cache.filter === 'function') {
                if (setting.cache.filter(res.data)) {
                    xhrCache.set(cacheKey, res.data);
                }
            } else {
                xhrCache.set(cacheKey, res.data);
            }
        }
        return res.data;
    })
        .catch((error) => {
            console.log(error);
            if (error.status === 504) {
                console.log('网络出错,请检测您的网络是否良好');
            }
        });
};

/**
 * 自定义xhr
 * @param opt.baseUrl
 * @return {*}
 */
function customXhr(opt) {
    return function (set) {
        set.url = opt.baseUrl + set.url;
        return xhr(set);
    };
}

export default xhr;
export {xhrCache, customXhr};